@@ -3,18 +3,18 @@ import json
 import logging
 import os
 import urllib
-
 from time import sleep
 from typing import Dict
 
 import aiohttp
 import requests
-
 from requests.exceptions import RequestException
 
 from moodle_dl.config import ConfigHelper
-from moodle_dl.types import MoodleURL, MoodleDlOpts
-from moodle_dl.utils import SslHelper, PathTools as PT, MoodleDLCookieJar
+from moodle_dl.types import MoodleDlOpts, MoodleURL
+from moodle_dl.utils import MoodleDLCookieJar
+from moodle_dl.utils import PathTools as PT
+from moodle_dl.utils import SslHelper
 
 
 class RequestHelper:
@@ -71,6 +71,7 @@ class RequestHelper:
         try:
             response = session.post(url, data=data_urlencoded, headers=self.RQ_HEADER, timeout=60)
         except RequestException as error:
+            self.log_failed_request(url, data)
             raise ConnectionError(f"Connection error: {str(error)}") from None
 
         if cookie_jar_path is not None:
@@ -100,6 +101,7 @@ class RequestHelper:
         try:
             response = session.get(url, headers=self.RQ_HEADER, timeout=60)
         except RequestException as error:
+            self.log_failed_request(url, None)
             raise ConnectionError(f"Connection error: {str(error)}") from None
 
         if cookie_jar_path is not None:
@@ -135,7 +137,8 @@ class RequestHelper:
                         raise_for_status=True,
                     ) as resp:
                         resp_json = await resp.json()
-                        resp_url = resp.url
+                    self.check_json_for_moodle_error(resp_json, url, data)
+                    self.log_response(function, data, str(resp.url), resp_json)
                     break
                 except (aiohttp.client_exceptions.ClientError, OSError, ValueError) as req_err:
                     if (isinstance(req_err, aiohttp.client_exceptions.ClientResponseError)) and (
@@ -155,9 +158,6 @@ class RequestHelper:
                         continue
                     raise ConnectionError(f"Connection error: {req_err}") from None
 
-        self.check_json_for_moodle_error(resp_json)
-        self.log_response(function, data, resp_url, resp_json)
-
         return resp_json
 
     def post(self, function: str, data: Dict[str, str] = None, timeout: int = 60) -> Dict:
@@ -192,7 +192,7 @@ class RequestHelper:
             except RequestException as req_err:
                 raise ConnectionError(f"Connection error: {req_err}") from None
 
-        json_result = self._initial_parse(response)
+        json_result = self._initial_parse(response, url, data)
         self.log_response(function, data, response.url, json_result)
 
         return json_result
@@ -253,7 +253,7 @@ class RequestHelper:
         except RequestException as error:
             raise ConnectionError(f"Connection error: {str(error)}") from None
 
-        return self._initial_parse(response)
+        return self._initial_parse(response, f'{self.url_base}login/token.php', 'censored')
 
     @staticmethod
     def _check_response_code(response):
@@ -266,7 +266,7 @@ class RequestHelper:
                 + f'\nResponse: {response.text}'
             )
 
-    def _initial_parse(self, response) -> object:
+    def _initial_parse(self, response, url: str, data: Dict) -> object:
         """
         The first time parsing the result of a REST request.
         It is checked for known errors.
@@ -288,12 +288,16 @@ class RequestHelper:
                 + f' response: {response.text}.\nError: {error}'
             ) from None
 
-        self.check_json_for_moodle_error(resp_json)
+        self.check_json_for_moodle_error(resp_json, url, data)
         return resp_json
 
-    def check_json_for_moodle_error(self, resp_json: Dict):
+    def log_failed_request(self, url: str, data: Dict):
+        logging.debug('Details about the failed request:\nURL: %s\nBody: %s', url, data)
+
+    def check_json_for_moodle_error(self, resp_json: Dict, url: str, data: Dict):
         # Check for known errors
         if 'error' in resp_json:
+            self.log_failed_request(url, data)
             raise RequestRejectedError(
                 'The Moodle System rejected the Request.'
                 + f" Details: {resp_json.get('error', '')} (Errorcode: {resp_json.get('errorcode', '')},"
@@ -302,6 +306,7 @@ class RequestHelper:
             )
 
         if 'exception' in resp_json:
+            self.log_failed_request(url, data)
             errorcode = resp_json.get('errorcode', '')
 
             if errorcode == 'invalidtoken':
